Class: Aws::ECR::Types::CreateRepositoryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#encryption_configurationTypes::EncryptionConfiguration

The encryption configuration for the repository. This determines how the contents of your repository are encrypted at rest.



661
662
663
664
665
666
667
668
669
670
671
# File 'lib/aws-sdk-ecr/types.rb', line 661

class CreateRepositoryRequest < Struct.new(
  :registry_id,
  :repository_name,
  :tags,
  :image_tag_mutability,
  :image_tag_mutability_exclusion_filters,
  :image_scanning_configuration,
  :encryption_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#image_scanning_configurationTypes::ImageScanningConfiguration

The imageScanningConfiguration parameter is being deprecated, in favor of specifying the image scanning configuration at the registry level. For more information, see PutRegistryScanningConfiguration.

The image scanning configuration for the repository. This determines whether images are scanned for known vulnerabilities after being pushed to the repository.



661
662
663
664
665
666
667
668
669
670
671
# File 'lib/aws-sdk-ecr/types.rb', line 661

class CreateRepositoryRequest < Struct.new(
  :registry_id,
  :repository_name,
  :tags,
  :image_tag_mutability,
  :image_tag_mutability_exclusion_filters,
  :image_scanning_configuration,
  :encryption_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#image_tag_mutabilityString

The tag mutability setting for the repository. If this parameter is omitted, the default setting of MUTABLE will be used which will allow image tags to be overwritten. If IMMUTABLE is specified, all image tags within the repository will be immutable which will prevent them from being overwritten.

Returns:

  • (String)


661
662
663
664
665
666
667
668
669
670
671
# File 'lib/aws-sdk-ecr/types.rb', line 661

class CreateRepositoryRequest < Struct.new(
  :registry_id,
  :repository_name,
  :tags,
  :image_tag_mutability,
  :image_tag_mutability_exclusion_filters,
  :image_scanning_configuration,
  :encryption_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#image_tag_mutability_exclusion_filtersArray<Types::ImageTagMutabilityExclusionFilter>

A list of filters that specify which image tags should be excluded from the repository’s image tag mutability setting.



661
662
663
664
665
666
667
668
669
670
671
# File 'lib/aws-sdk-ecr/types.rb', line 661

class CreateRepositoryRequest < Struct.new(
  :registry_id,
  :repository_name,
  :tags,
  :image_tag_mutability,
  :image_tag_mutability_exclusion_filters,
  :image_scanning_configuration,
  :encryption_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#registry_idString

The Amazon Web Services account ID associated with the registry to create the repository. If you do not specify a registry, the default registry is assumed.

Returns:

  • (String)


661
662
663
664
665
666
667
668
669
670
671
# File 'lib/aws-sdk-ecr/types.rb', line 661

class CreateRepositoryRequest < Struct.new(
  :registry_id,
  :repository_name,
  :tags,
  :image_tag_mutability,
  :image_tag_mutability_exclusion_filters,
  :image_scanning_configuration,
  :encryption_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#repository_nameString

The name to use for the repository. The repository name may be specified on its own (such as nginx-web-app) or it can be prepended with a namespace to group the repository into a category (such as project-a/nginx-web-app).

The repository name must start with a letter and can only contain lowercase letters, numbers, hyphens, underscores, and forward slashes.

Returns:

  • (String)


661
662
663
664
665
666
667
668
669
670
671
# File 'lib/aws-sdk-ecr/types.rb', line 661

class CreateRepositoryRequest < Struct.new(
  :registry_id,
  :repository_name,
  :tags,
  :image_tag_mutability,
  :image_tag_mutability_exclusion_filters,
  :image_scanning_configuration,
  :encryption_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

The metadata that you apply to the repository to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define. Tag keys can have a maximum character length of 128 characters, and tag values can have a maximum length of 256 characters.

Returns:



661
662
663
664
665
666
667
668
669
670
671
# File 'lib/aws-sdk-ecr/types.rb', line 661

class CreateRepositoryRequest < Struct.new(
  :registry_id,
  :repository_name,
  :tags,
  :image_tag_mutability,
  :image_tag_mutability_exclusion_filters,
  :image_scanning_configuration,
  :encryption_configuration)
  SENSITIVE = []
  include Aws::Structure
end