Class: Aws::ECR::Types::DeleteRepositoryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#forceBoolean

If true, deleting the repository force deletes the contents of the repository. If false, the repository must be empty before attempting to delete it.



993
994
995
996
997
998
999
# File 'lib/aws-sdk-ecr/types.rb', line 993

class DeleteRepositoryRequest < Struct.new(
  :registry_id,
  :repository_name,
  :force)
  SENSITIVE = []
  include Aws::Structure
end

#registry_idString

The Amazon Web Services account ID associated with the registry that contains the repository to delete. If you do not specify a registry, the default registry is assumed.



993
994
995
996
997
998
999
# File 'lib/aws-sdk-ecr/types.rb', line 993

class DeleteRepositoryRequest < Struct.new(
  :registry_id,
  :repository_name,
  :force)
  SENSITIVE = []
  include Aws::Structure
end

#repository_nameString

The name of the repository to delete.



993
994
995
996
997
998
999
# File 'lib/aws-sdk-ecr/types.rb', line 993

class DeleteRepositoryRequest < Struct.new(
  :registry_id,
  :repository_name,
  :force)
  SENSITIVE = []
  include Aws::Structure
end