Class: Aws::ECR::Types::DescribeRepositoriesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECR::Types::DescribeRepositoriesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of repository results returned by
DescribeRepositoriesin paginated output. -
#next_token ⇒ String
The
nextTokenvalue returned from a previous paginatedDescribeRepositoriesrequest wheremaxResultswas used and the results exceeded the value of that parameter. -
#registry_id ⇒ String
The Amazon Web Services account ID associated with the registry that contains the repositories to be described.
-
#repository_names ⇒ Array<String>
A list of repositories to describe.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of repository results returned by
DescribeRepositories in paginated output. When this parameter is
used, DescribeRepositories only returns maxResults results in a
single page along with a nextToken response element. The remaining
results of the initial request can be seen by sending another
DescribeRepositories request with the returned nextToken value.
This value can be between 1 and 1000. If this parameter is not used,
then DescribeRepositories returns up to 100 results and a
nextToken value, if applicable. This option cannot be used when
you specify repositories with repositoryNames.
1483 1484 1485 1486 1487 1488 1489 1490 |
# File 'lib/aws-sdk-ecr/types.rb', line 1483 class DescribeRepositoriesRequest < Struct.new( :registry_id, :repository_names, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a previous paginated
DescribeRepositories request where maxResults was used and the
results exceeded the value of that parameter. Pagination continues
from the end of the previous results that returned the nextToken
value. This value is null when there are no more results to
return. This option cannot be used when you specify repositories
with repositoryNames.
1483 1484 1485 1486 1487 1488 1489 1490 |
# File 'lib/aws-sdk-ecr/types.rb', line 1483 class DescribeRepositoriesRequest < Struct.new( :registry_id, :repository_names, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#registry_id ⇒ String
The Amazon Web Services account ID associated with the registry that contains the repositories to be described. If you do not specify a registry, the default registry is assumed.
1483 1484 1485 1486 1487 1488 1489 1490 |
# File 'lib/aws-sdk-ecr/types.rb', line 1483 class DescribeRepositoriesRequest < Struct.new( :registry_id, :repository_names, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#repository_names ⇒ Array<String>
A list of repositories to describe. If this parameter is omitted, then all repositories in a registry are described.
1483 1484 1485 1486 1487 1488 1489 1490 |
# File 'lib/aws-sdk-ecr/types.rb', line 1483 class DescribeRepositoriesRequest < Struct.new( :registry_id, :repository_names, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |