Class: Aws::ECR::Types::DescribeRepositoryCreationTemplatesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ecr/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of repository results returned by DescribeRepositoryCreationTemplatesRequest in paginated output. When this parameter is used, DescribeRepositoryCreationTemplatesRequest only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another DescribeRepositoryCreationTemplatesRequest request with the returned nextToken value. This value can be between 1 and 1000. If this parameter is not used, then DescribeRepositoryCreationTemplatesRequest returns up to 100 results and a nextToken value, if applicable.

Returns:

  • (Integer)


1551
1552
1553
1554
1555
1556
1557
# File 'lib/aws-sdk-ecr/types.rb', line 1551

class DescribeRepositoryCreationTemplatesRequest < Struct.new(
  :prefixes,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The nextToken value returned from a previous paginated DescribeRepositoryCreationTemplates request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return.

This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes.

Returns:

  • (String)


1551
1552
1553
1554
1555
1556
1557
# File 'lib/aws-sdk-ecr/types.rb', line 1551

class DescribeRepositoryCreationTemplatesRequest < Struct.new(
  :prefixes,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#prefixesArray<String>

The repository namespace prefixes associated with the repository creation templates to describe. If this value is not specified, all repository creation templates are returned.

Returns:

  • (Array<String>)


1551
1552
1553
1554
1555
1556
1557
# File 'lib/aws-sdk-ecr/types.rb', line 1551

class DescribeRepositoryCreationTemplatesRequest < Struct.new(
  :prefixes,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end