Class: Aws::ECR::Types::DescribeRepositoryCreationTemplatesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECR::Types::DescribeRepositoryCreationTemplatesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The
nextTokenvalue to include in a futureDescribeRepositoryCreationTemplatesrequest. -
#registry_id ⇒ String
The registry ID associated with the request.
-
#repository_creation_templates ⇒ Array<Types::RepositoryCreationTemplate>
The details of the repository creation templates.
Instance Attribute Details
#next_token ⇒ String
The nextToken value to include in a future
DescribeRepositoryCreationTemplates request. When the results of a
DescribeRepositoryCreationTemplates request exceed maxResults,
this value can be used to retrieve the next page of results. This
value is null when there are no more results to return.
1577 1578 1579 1580 1581 1582 1583 |
# File 'lib/aws-sdk-ecr/types.rb', line 1577 class DescribeRepositoryCreationTemplatesResponse < Struct.new( :registry_id, :repository_creation_templates, :next_token) SENSITIVE = [] include Aws::Structure end |
#registry_id ⇒ String
The registry ID associated with the request.
1577 1578 1579 1580 1581 1582 1583 |
# File 'lib/aws-sdk-ecr/types.rb', line 1577 class DescribeRepositoryCreationTemplatesResponse < Struct.new( :registry_id, :repository_creation_templates, :next_token) SENSITIVE = [] include Aws::Structure end |
#repository_creation_templates ⇒ Array<Types::RepositoryCreationTemplate>
The details of the repository creation templates.
1577 1578 1579 1580 1581 1582 1583 |
# File 'lib/aws-sdk-ecr/types.rb', line 1577 class DescribeRepositoryCreationTemplatesResponse < Struct.new( :registry_id, :repository_creation_templates, :next_token) SENSITIVE = [] include Aws::Structure end |