Class: Aws::ECR::Types::ListPullTimeUpdateExclusionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECR::Types::ListPullTimeUpdateExclusionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of pull time update exclusion results returned by
ListPullTimeUpdateExclusionsin paginated output. -
#next_token ⇒ String
The
nextTokenvalue returned from a previous paginatedListPullTimeUpdateExclusionsrequest wheremaxResultswas used and the results exceeded the value of that parameter.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of pull time update exclusion results returned by
ListPullTimeUpdateExclusions in paginated output. When this
parameter is used, ListPullTimeUpdateExclusions only returns
maxResults results in a single page along with a nextToken
response element. The remaining results of the initial request can
be seen by sending another ListPullTimeUpdateExclusions request
with the returned nextToken value. This value can be between 1 and
1000. If this parameter is not used, then
ListPullTimeUpdateExclusions returns up to 100 results and a
nextToken value, if applicable.
3377 3378 3379 3380 3381 3382 |
# File 'lib/aws-sdk-ecr/types.rb', line 3377 class ListPullTimeUpdateExclusionsRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a previous paginated
ListPullTimeUpdateExclusions request where maxResults was used
and the results exceeded the value of that parameter. Pagination
continues from the end of the previous results that returned the
nextToken value. This value is null when there are no more
results to return.
3377 3378 3379 3380 3381 3382 |
# File 'lib/aws-sdk-ecr/types.rb', line 3377 class ListPullTimeUpdateExclusionsRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |