Class: Aws::ECR::Types::ListTagsForResourceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECR::Types::ListTagsForResourceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) that identifies the resource for which to list the tags.
Instance Attribute Details
#resource_arn ⇒ String
The Amazon Resource Name (ARN) that identifies the resource for which to list the tags. Currently, the only supported resource is an Amazon ECR repository.
3413 3414 3415 3416 3417 |
# File 'lib/aws-sdk-ecr/types.rb', line 3413 class ListTagsForResourceRequest < Struct.new( :resource_arn) SENSITIVE = [] include Aws::Structure end |