Class: Aws::ECR::Types::PutAccountSettingRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECR::Types::PutAccountSettingRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the account setting, such as ‘BASIC_SCAN_TYPE_VERSION`, `REGISTRY_POLICY_SCOPE`, or `BLOB_MOUNTING`.
-
#value ⇒ String
Setting value that is specified.
Instance Attribute Details
#name ⇒ String
The name of the account setting, such as ‘BASIC_SCAN_TYPE_VERSION`, `REGISTRY_POLICY_SCOPE`, or `BLOB_MOUNTING`.
3594 3595 3596 3597 3598 3599 |
# File 'lib/aws-sdk-ecr/types.rb', line 3594 class PutAccountSettingRequest < Struct.new( :name, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
Setting value that is specified. Valid value for basic scan type: ‘AWS_NATIVE`. Valid values for registry policy scope: `V1` or `V2`. Valid values for blob mounting: `ENABLED` or `DISABLED`.
3594 3595 3596 3597 3598 3599 |
# File 'lib/aws-sdk-ecr/types.rb', line 3594 class PutAccountSettingRequest < Struct.new( :name, :value) SENSITIVE = [] include Aws::Structure end |