Class: Aws::ECR::Types::PutImageTagMutabilityRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECR::Types::PutImageTagMutabilityRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#image_tag_mutability ⇒ String
The tag mutability setting for the repository.
-
#image_tag_mutability_exclusion_filters ⇒ Array<Types::ImageTagMutabilityExclusionFilter>
A list of filters that specify which image tags should be excluded from the image tag mutability setting being applied.
-
#registry_id ⇒ String
The Amazon Web Services account ID associated with the registry that contains the repository in which to update the image tag mutability settings.
-
#repository_name ⇒ String
The name of the repository in which to update the image tag mutability settings.
Instance Attribute Details
#image_tag_mutability ⇒ String
The tag mutability setting for the repository. If MUTABLE is specified, image tags can be overwritten. If IMMUTABLE is specified, all image tags within the repository will be immutable which will prevent them from being overwritten.
3749 3750 3751 3752 3753 3754 3755 3756 |
# File 'lib/aws-sdk-ecr/types.rb', line 3749 class PutImageTagMutabilityRequest < Struct.new( :registry_id, :repository_name, :image_tag_mutability, :image_tag_mutability_exclusion_filters) SENSITIVE = [] include Aws::Structure end |
#image_tag_mutability_exclusion_filters ⇒ Array<Types::ImageTagMutabilityExclusionFilter>
A list of filters that specify which image tags should be excluded from the image tag mutability setting being applied.
3749 3750 3751 3752 3753 3754 3755 3756 |
# File 'lib/aws-sdk-ecr/types.rb', line 3749 class PutImageTagMutabilityRequest < Struct.new( :registry_id, :repository_name, :image_tag_mutability, :image_tag_mutability_exclusion_filters) SENSITIVE = [] include Aws::Structure end |
#registry_id ⇒ String
The Amazon Web Services account ID associated with the registry that contains the repository in which to update the image tag mutability settings. If you do not specify a registry, the default registry is assumed.
3749 3750 3751 3752 3753 3754 3755 3756 |
# File 'lib/aws-sdk-ecr/types.rb', line 3749 class PutImageTagMutabilityRequest < Struct.new( :registry_id, :repository_name, :image_tag_mutability, :image_tag_mutability_exclusion_filters) SENSITIVE = [] include Aws::Structure end |
#repository_name ⇒ String
The name of the repository in which to update the image tag mutability settings.
3749 3750 3751 3752 3753 3754 3755 3756 |
# File 'lib/aws-sdk-ecr/types.rb', line 3749 class PutImageTagMutabilityRequest < Struct.new( :registry_id, :repository_name, :image_tag_mutability, :image_tag_mutability_exclusion_filters) SENSITIVE = [] include Aws::Structure end |