Class: Aws::ECR::Types::TagResourceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECR::Types::TagResourceRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the the resource to which to add tags.
-
#tags ⇒ Array<Types::Tag>
The tags to add to the resource.
Instance Attribute Details
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the the resource to which to add tags. Currently, the only supported resource is an Amazon ECR repository.
4901 4902 4903 4904 4905 4906 |
# File 'lib/aws-sdk-ecr/types.rb', line 4901 class TagResourceRequest < Struct.new( :resource_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The tags to add to the resource. A tag is an array of key-value pairs. Tag keys can have a maximum character length of 128 characters, and tag values can have a maximum length of 256 characters.
4901 4902 4903 4904 4905 4906 |
# File 'lib/aws-sdk-ecr/types.rb', line 4901 class TagResourceRequest < Struct.new( :resource_arn, :tags) SENSITIVE = [] include Aws::Structure end |