Class: Aws::ECR::Types::UpdateRepositoryCreationTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECR::Types::UpdateRepositoryCreationTemplateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#applied_for ⇒ Array<String>
Updates the list of enumerable strings representing the Amazon ECR repository creation scenarios that this template will apply towards.
-
#custom_role_arn ⇒ String
The ARN of the role to be assumed by Amazon ECR.
-
#description ⇒ String
A description for the repository creation template.
-
#encryption_configuration ⇒ Types::EncryptionConfigurationForRepositoryCreationTemplate
The encryption configuration to associate with the repository creation template.
-
#image_tag_mutability ⇒ String
Updates the tag mutability setting for the repository.
-
#image_tag_mutability_exclusion_filters ⇒ Array<Types::ImageTagMutabilityExclusionFilter>
A list of filters that specify which image tags should be excluded from the repository creation template's image tag mutability setting.
-
#lifecycle_policy ⇒ String
Updates the lifecycle policy associated with the specified repository creation template.
-
#prefix ⇒ String
The repository namespace prefix that matches an existing repository creation template in the registry.
-
#repository_policy ⇒ String
Updates the repository policy created using the template.
-
#resource_tags ⇒ Array<Types::Tag>
The metadata to apply to the repository to help you categorize and organize.
Instance Attribute Details
#applied_for ⇒ Array<String>
Updates the list of enumerable strings representing the Amazon ECR
repository creation scenarios that this template will apply towards.
The supported scenarios are PULL_THROUGH_CACHE, REPLICATION, and
CREATE_ON_PUSH
5305 5306 5307 5308 5309 5310 5311 5312 5313 5314 5315 5316 5317 5318 |
# File 'lib/aws-sdk-ecr/types.rb', line 5305 class UpdateRepositoryCreationTemplateRequest < Struct.new( :prefix, :description, :encryption_configuration, :resource_tags, :image_tag_mutability, :image_tag_mutability_exclusion_filters, :repository_policy, :lifecycle_policy, :applied_for, :custom_role_arn) SENSITIVE = [] include Aws::Structure end |
#custom_role_arn ⇒ String
The ARN of the role to be assumed by Amazon ECR. This role must be in the same account as the registry that you are configuring. Amazon ECR will assume your supplied role when the customRoleArn is specified. When this field isn't specified, Amazon ECR will use the service-linked role for the repository creation template.
5305 5306 5307 5308 5309 5310 5311 5312 5313 5314 5315 5316 5317 5318 |
# File 'lib/aws-sdk-ecr/types.rb', line 5305 class UpdateRepositoryCreationTemplateRequest < Struct.new( :prefix, :description, :encryption_configuration, :resource_tags, :image_tag_mutability, :image_tag_mutability_exclusion_filters, :repository_policy, :lifecycle_policy, :applied_for, :custom_role_arn) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the repository creation template.
5305 5306 5307 5308 5309 5310 5311 5312 5313 5314 5315 5316 5317 5318 |
# File 'lib/aws-sdk-ecr/types.rb', line 5305 class UpdateRepositoryCreationTemplateRequest < Struct.new( :prefix, :description, :encryption_configuration, :resource_tags, :image_tag_mutability, :image_tag_mutability_exclusion_filters, :repository_policy, :lifecycle_policy, :applied_for, :custom_role_arn) SENSITIVE = [] include Aws::Structure end |
#encryption_configuration ⇒ Types::EncryptionConfigurationForRepositoryCreationTemplate
The encryption configuration to associate with the repository creation template.
5305 5306 5307 5308 5309 5310 5311 5312 5313 5314 5315 5316 5317 5318 |
# File 'lib/aws-sdk-ecr/types.rb', line 5305 class UpdateRepositoryCreationTemplateRequest < Struct.new( :prefix, :description, :encryption_configuration, :resource_tags, :image_tag_mutability, :image_tag_mutability_exclusion_filters, :repository_policy, :lifecycle_policy, :applied_for, :custom_role_arn) SENSITIVE = [] include Aws::Structure end |
#image_tag_mutability ⇒ String
Updates the tag mutability setting for the repository. If this
parameter is omitted, the default setting of MUTABLE will be used
which will allow image tags to be overwritten. If IMMUTABLE is
specified, all image tags within the repository will be immutable
which will prevent them from being overwritten.
5305 5306 5307 5308 5309 5310 5311 5312 5313 5314 5315 5316 5317 5318 |
# File 'lib/aws-sdk-ecr/types.rb', line 5305 class UpdateRepositoryCreationTemplateRequest < Struct.new( :prefix, :description, :encryption_configuration, :resource_tags, :image_tag_mutability, :image_tag_mutability_exclusion_filters, :repository_policy, :lifecycle_policy, :applied_for, :custom_role_arn) SENSITIVE = [] include Aws::Structure end |
#image_tag_mutability_exclusion_filters ⇒ Array<Types::ImageTagMutabilityExclusionFilter>
A list of filters that specify which image tags should be excluded from the repository creation template's image tag mutability setting.
5305 5306 5307 5308 5309 5310 5311 5312 5313 5314 5315 5316 5317 5318 |
# File 'lib/aws-sdk-ecr/types.rb', line 5305 class UpdateRepositoryCreationTemplateRequest < Struct.new( :prefix, :description, :encryption_configuration, :resource_tags, :image_tag_mutability, :image_tag_mutability_exclusion_filters, :repository_policy, :lifecycle_policy, :applied_for, :custom_role_arn) SENSITIVE = [] include Aws::Structure end |
#lifecycle_policy ⇒ String
Updates the lifecycle policy associated with the specified repository creation template.
5305 5306 5307 5308 5309 5310 5311 5312 5313 5314 5315 5316 5317 5318 |
# File 'lib/aws-sdk-ecr/types.rb', line 5305 class UpdateRepositoryCreationTemplateRequest < Struct.new( :prefix, :description, :encryption_configuration, :resource_tags, :image_tag_mutability, :image_tag_mutability_exclusion_filters, :repository_policy, :lifecycle_policy, :applied_for, :custom_role_arn) SENSITIVE = [] include Aws::Structure end |
#prefix ⇒ String
The repository namespace prefix that matches an existing repository
creation template in the registry. All repositories created using
this namespace prefix will have the settings defined in this
template applied. For example, a prefix of prod would apply to all
repositories beginning with prod/. This includes a repository
named prod/team1 as well as a repository named prod/repository1.
To apply a template to all repositories in your registry that don't
have an associated creation template, you can use ROOT as the
prefix.
5305 5306 5307 5308 5309 5310 5311 5312 5313 5314 5315 5316 5317 5318 |
# File 'lib/aws-sdk-ecr/types.rb', line 5305 class UpdateRepositoryCreationTemplateRequest < Struct.new( :prefix, :description, :encryption_configuration, :resource_tags, :image_tag_mutability, :image_tag_mutability_exclusion_filters, :repository_policy, :lifecycle_policy, :applied_for, :custom_role_arn) SENSITIVE = [] include Aws::Structure end |
#repository_policy ⇒ String
Updates the repository policy created using the template. A repository policy is a permissions policy associated with a repository to control access permissions.
5305 5306 5307 5308 5309 5310 5311 5312 5313 5314 5315 5316 5317 5318 |
# File 'lib/aws-sdk-ecr/types.rb', line 5305 class UpdateRepositoryCreationTemplateRequest < Struct.new( :prefix, :description, :encryption_configuration, :resource_tags, :image_tag_mutability, :image_tag_mutability_exclusion_filters, :repository_policy, :lifecycle_policy, :applied_for, :custom_role_arn) SENSITIVE = [] include Aws::Structure end |
#resource_tags ⇒ Array<Types::Tag>
The metadata to apply to the repository to help you categorize and organize. Each tag consists of a key and an optional value, both of which you define. Tag keys can have a maximum character length of 128 characters, and tag values can have a maximum length of 256 characters.
5305 5306 5307 5308 5309 5310 5311 5312 5313 5314 5315 5316 5317 5318 |
# File 'lib/aws-sdk-ecr/types.rb', line 5305 class UpdateRepositoryCreationTemplateRequest < Struct.new( :prefix, :description, :encryption_configuration, :resource_tags, :image_tag_mutability, :image_tag_mutability_exclusion_filters, :repository_policy, :lifecycle_policy, :applied_for, :custom_role_arn) SENSITIVE = [] include Aws::Structure end |