Class: Aws::ECR::Waiters::LifecyclePolicyPreviewComplete
- Inherits:
-
Object
- Object
- Aws::ECR::Waiters::LifecyclePolicyPreviewComplete
- Defined in:
- lib/aws-sdk-ecr/waiters.rb,
sig/waiters.rbs
Overview
Wait until a lifecycle policy preview request is complete and results can be accessed
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ LifecyclePolicyPreviewComplete
constructor
A new instance of LifecyclePolicyPreviewComplete.
-
#wait(params = {}) ⇒ Types::GetLifecyclePolicyPreviewResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ LifecyclePolicyPreviewComplete
Returns a new instance of LifecyclePolicyPreviewComplete.
131 132 |
# File 'lib/aws-sdk-ecr/waiters.rb', line 131
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
163 164 165 |
# File 'lib/aws-sdk-ecr/waiters.rb', line 163 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetLifecyclePolicyPreviewResponse
Returns a response object which responds to the following methods:
- #registry_id => String
- #repository_name => String
- #lifecycle_policy_text => String
- #status => String
- #next_token => String
- #preview_results => Array<Types::LifecyclePolicyPreviewResult>
- #summary => Types::LifecyclePolicyPreviewSummary
158 |
# File 'lib/aws-sdk-ecr/waiters.rb', line 158
def wait: (
|