Class: Aws::ECR::Types::DescribeRepositoryCreationTemplatesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECR::Types::DescribeRepositoryCreationTemplatesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of repository results returned by
DescribeRepositoryCreationTemplatesRequestin paginated output. -
#next_token ⇒ String
The
nextTokenvalue returned from a previous paginatedDescribeRepositoryCreationTemplatesrequest wheremaxResultswas used and the results exceeded the value of that parameter. -
#prefixes ⇒ Array<String>
The repository namespace prefixes associated with the repository creation templates to describe.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of repository results returned by
DescribeRepositoryCreationTemplatesRequest in paginated output.
When this parameter is used,
DescribeRepositoryCreationTemplatesRequest only returns
maxResults results in a single page along with a nextToken
response element. The remaining results of the initial request can
be seen by sending another
DescribeRepositoryCreationTemplatesRequest request with the
returned nextToken value. This value can be between 1 and 1000. If
this parameter is not used, then
DescribeRepositoryCreationTemplatesRequest returns up to 100
results and a nextToken value, if applicable.
1551 1552 1553 1554 1555 1556 1557 |
# File 'lib/aws-sdk-ecr/types.rb', line 1551 class DescribeRepositoryCreationTemplatesRequest < Struct.new( :prefixes, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a previous paginated
DescribeRepositoryCreationTemplates request where maxResults was
used and the results exceeded the value of that parameter.
Pagination continues from the end of the previous results that
returned the nextToken value. This value is null when there are
no more results to return.
1551 1552 1553 1554 1555 1556 1557 |
# File 'lib/aws-sdk-ecr/types.rb', line 1551 class DescribeRepositoryCreationTemplatesRequest < Struct.new( :prefixes, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#prefixes ⇒ Array<String>
The repository namespace prefixes associated with the repository creation templates to describe. If this value is not specified, all repository creation templates are returned.
1551 1552 1553 1554 1555 1556 1557 |
# File 'lib/aws-sdk-ecr/types.rb', line 1551 class DescribeRepositoryCreationTemplatesRequest < Struct.new( :prefixes, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |