Class: Aws::ECR::Types::ListImageReferrersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECR::Types::ListImageReferrersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecr/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter ⇒ Types::ListImageReferrersFilter
The filter key and value with which to filter your
ListImageReferrersresults. -
#max_results ⇒ Integer
The maximum number of image referrer results returned by
ListImageReferrersin paginated output. -
#next_token ⇒ String
The
nextTokenvalue returned from a previous paginatedListImageReferrersrequest wheremaxResultswas used and the results exceeded the value of that parameter. -
#registry_id ⇒ String
The Amazon Web Services account ID associated with the registry that contains the repository in which to list image referrers.
-
#repository_name ⇒ String
The name of the repository that contains the subject image.
-
#subject_id ⇒ Types::SubjectIdentifier
An object containing the image digest of the subject image for which to retrieve associated artifacts.
Instance Attribute Details
#filter ⇒ Types::ListImageReferrersFilter
The filter key and value with which to filter your
ListImageReferrers results. If no filter is specified, only
artifacts with ACTIVE status are returned.
3222 3223 3224 3225 3226 3227 3228 3229 3230 3231 |
# File 'lib/aws-sdk-ecr/types.rb', line 3222 class ListImageReferrersRequest < Struct.new( :registry_id, :repository_name, :subject_id, :filter, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of image referrer results returned by
ListImageReferrers in paginated output. When this parameter is
used, ListImageReferrers only returns maxResults results in a
single page along with a nextToken response element. The remaining
results of the initial request can be seen by sending another
ListImageReferrers request with the returned nextToken value.
This value can be between 1 and 50. If this parameter is not used,
then ListImageReferrers returns up to 20 results and a nextToken
value, if applicable.
3222 3223 3224 3225 3226 3227 3228 3229 3230 3231 |
# File 'lib/aws-sdk-ecr/types.rb', line 3222 class ListImageReferrersRequest < Struct.new( :registry_id, :repository_name, :subject_id, :filter, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The nextToken value returned from a previous paginated
ListImageReferrers request where maxResults was used and the
results exceeded the value of that parameter. Pagination continues
from the end of the previous results that returned the nextToken
value. This value is null when there are no more results to
return.
3222 3223 3224 3225 3226 3227 3228 3229 3230 3231 |
# File 'lib/aws-sdk-ecr/types.rb', line 3222 class ListImageReferrersRequest < Struct.new( :registry_id, :repository_name, :subject_id, :filter, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#registry_id ⇒ String
The Amazon Web Services account ID associated with the registry that contains the repository in which to list image referrers. If you do not specify a registry, the default registry is assumed.
3222 3223 3224 3225 3226 3227 3228 3229 3230 3231 |
# File 'lib/aws-sdk-ecr/types.rb', line 3222 class ListImageReferrersRequest < Struct.new( :registry_id, :repository_name, :subject_id, :filter, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#repository_name ⇒ String
The name of the repository that contains the subject image.
3222 3223 3224 3225 3226 3227 3228 3229 3230 3231 |
# File 'lib/aws-sdk-ecr/types.rb', line 3222 class ListImageReferrersRequest < Struct.new( :registry_id, :repository_name, :subject_id, :filter, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#subject_id ⇒ Types::SubjectIdentifier
An object containing the image digest of the subject image for which to retrieve associated artifacts.
3222 3223 3224 3225 3226 3227 3228 3229 3230 3231 |
# File 'lib/aws-sdk-ecr/types.rb', line 3222 class ListImageReferrersRequest < Struct.new( :registry_id, :repository_name, :subject_id, :filter, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |