Class: Aws::ECR::Types::UnableToListUpstreamImageReferrersException
- Inherits:
-
Struct
- Object
- Struct
- Aws::ECR::Types::UnableToListUpstreamImageReferrersException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ecr/types.rb
Overview
The referrer or referrers were unable to be listed using the pull through cache rule. This is usually caused because of an issue with the Secrets Manager secret containing the credentials for the upstream registry.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
5043 5044 5045 5046 5047 |
# File 'lib/aws-sdk-ecr/types.rb', line 5043 class UnableToListUpstreamImageReferrersException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |